@@ -10,6 +10,9 @@
 #include "mixer.h"
 #include "str.h"
 #include "systemstub.h"
+#ifdef MAEMO
+#include "maemo.h"
+#endif
 
 static const char *_gameWindowTitle = "Bermuda Syndrome";
 
@@ -222,6 +225,11 @@ void Game::updateKeysPressedTable() {
 		if (slot >= 1 && slot <= 999) {
 			_stateSlot = slot;
 			debug(DBG_INFO, "Current game state slot is %d", _stateSlot);
+#ifdef MAEMO
+			char msg[255];
+			sprintf(msg, "Current game state slot is %d", _stateSlot);
+			show_notification(msg);
+#endif
 		}
 		_stub->_pi.stateSlot = 0;
 	}
