@@ -5,7 +5,9 @@
 
 #include "game.h"
 #include "systemstub.h"
-
+#ifdef MAEMO
+#include "maemo.h"
+#endif
 static SystemStub *g_stub;
 
 static const char *USAGE =
@@ -54,6 +56,10 @@ int main(int argc, char *argv[]) {
 	g_debugMask = DBG_INFO; // | DBG_GAME | DBG_OPCODES | DBG_DIALOGUE;
 	g_stub = SystemStub_SDL_create();
 	atexit(exitMain);
+
+#ifdef MAEMO
+	maemo_init();
+#endif
 	Game *g = new Game(g_stub, dataPath, savePath, musicPath);
 	g->mainLoop();
 	delete g;
